#

##

##

###

###

    	info

    	summary

    		Info "moves" for retrieving information
    		about the "genome", etc.

    	objectives

    		genome info
    			"account balance"

    		organism info

    			"friends"
    				These are friends whose addresses
    				are rememberd.

    			"ignore"
    				These are organism that are ignored
    				because of:

    					( ) spamming
    					( ) fraud